﻿/**
 * \file   DCP8325L.h
 *
 * \brief  DCP8325L程控电源接口文件
 *         包括设备的打开、关闭，通信方式的选择，数据的读、写等操作
 *
 * \date   2013/05/1
**/

#ifndef _DCP8325L_H_
#define _DCP8325L_H_

#ifdef  DCP8325L_EXPORTS
#define DCP8325L_API    __declspec(dllexport)
#else
#define DCP8325L_API
#endif

#ifdef __cplusplus
extern "C" {
#endif

/*
 *  \brief 定义接口返回值
 */
#define DCP_SUCCESS             0    /* Success, No Error.                                 */
/* beginning-of-error-codes */
#define DCP_FAILURE             1    /* Failure, Error.                                    */
/* end-of-error-codes */

/*
 *  \brief  打开设备，并选择通信方式USB或LAN执行连接
 *          若pIpAddr值小于32，即dcp_open(0~31, 1000)，则选用USB接口进行连接，连接序号为pIpAddr的设备；
 *          若pIpAddr大于32时，则选用LAN通信模式进行连接，pIpAddr指向ip地址；
 *          仅当pIpAddr为正确的IP地址字符串时(例如：192.168.0.1，不需要端口号)，LAN通信模式才可能连接成功
 *  \return 根据接口定义的返回值而定
 */
DCP8325L_API int dcp_open(const char* pIpAddr = NULL, unsigned int nTimeout = 10000);

/*
 *  \brief  关闭设备
 */
DCP8325L_API void dcp_close();

/*
 *  \brief  执行读数据的SCPI命令，即带“?”的命令
 *  \param  pCommand    用于读数据的SCPI命令
 *          pReadBuf    读数据缓冲区，用于存放pCommand执行后返回的结果
 *          pBufLength  [IN]读数据缓冲区pReadBuf分配的字节长度
 *                      [OUT]读数据缓冲区pReadBuf中返回结果的数据字节长度
 *  \return 根据接口定义的返回值而定
 */
DCP8325L_API int dcp_read(const char * pCommand, char* pReadBuf, int* pBufLength);

/*
 *  \brief  执行写数据命令，即不带“?”的命令
 *  \param  pCommand  写数据缓冲区，即用于写数据的SCPI命令
 *  \return 根据接口定义的返回值而定
 */
DCP8325L_API int dcp_write(const char* pCommand);

#ifdef __cplusplus
}
#endif

#endif /* _DCP8325L_H_ */